\name{OptiPt}
\alias{OptiPt}
\alias{summary.eba}
\alias{print.summary.eba}
\alias{print.eba}
\alias{L}
\title{Elimination-by-aspects models}
\description{
  Fits a probabilistic choice model by maximum likelihood estimation.
}
\usage{
  OptiPt(M, A = 1:I, s = rep(1/J, J))

  summary.eba(object, ...)
}
\arguments{
  \item{M}{a square matrix or a data frame consisting of
    absolute frequencies}
  \item{A}{a list of vectors consisting of the stimulus aspects;
    the default is 1:I, where I is the number of stimuli}
  \item{s}{the starting vector with default 1/J for all parameters,
    where J is the number of parameters}
  \item{object}{an object of class \code{eba}}
  \item{...}{additional arguments affecting the summary produced}
}
\details{
  A is usually a list of vectors, the first element of each being a
  number from 1 to I; additional elements specify the aspects shared
  by several stimuli.
  When fitting a BTL model, A reduces to 1:I, i.e. there is one aspect
  per stimulus.

  The maximum likelihood estimation of the parameter values is
  carried out by \code{nlm}. The Hessian matrix, however, is
  approximated by \code{fdHess{nlme}}.
}
\value{
  \item{estimate}{a vector of parameter estimates}
  \item{se}{a vector of the standard errors of the parameter estimates}
  \item{ci95}{the 95\%-confidence intervals for the parameter estimates}
  \item{logL.eba}{the log-likelihood of the fitted model}
  \item{logL.sat}{the log-likelihood of the saturated (binomial) model}
  \item{goodness.of.fit}{the goodness of fit statistic including the
    likelihood ratio (-2logL), the degrees of freedom, and the p-value
    of the corresponig chi2 distribution}
  \item{u.scale}{the u-scale of the stimuli; one scale value is defined
    as the sum of aspect values (parameters) that characterize a given
    stimulus}
  \item{hessian}{the Hessian matrix of the likelihood function}
  \item{cov.p}{the covariance matrix of the model parameters}
  \item{chi.alt}{the Pearson chi2 goodness of fit statistic}
  \item{fitted}{the fitted paired-comparison matrix}
}
\references{
  Wickelmaier, F., & Schmid, C. (2004). A Matlab function to estimate
  choice model parameters from paired-comparison data.
  \emph{Behavior Research Methods, Instruments, and Computers},
  \bold{36}, 29-40.

  Bradley, R.A. (1984). Paired comparisons: some basic procedures and
  examples. In P.R. Krishnaiah & P.K. Sen (eds.),
  \emph{Handbook of Statistics, Volume 4}. Amsterdam: Elsevier.

  Tversky, A. (1972). Elimination by aspects: A theory of choice.
  \emph{Psychological Review}, \bold{79}, 281-299.

  Tversky, A., & Sattath, S. (1979). Preference trees.
  \emph{Psychological Review}, \bold{86}, 542-573.
}
\author{Florian Wickelmaier \email{wickelmaier@web.de}}
\seealso{
  \code{\link{strans}}, \code{\link{cov.u}}, \code{\link{nlm}}.
}
\examples{
data(rugr)  # absolute choice frequencies
A = list(c(1,10),c(2,10),c(3,10),c(4,11),c(5,11),c(6,11),
         c(7,12),c(8,12),c(9,12))  # the structure of aspects
eba = OptiPt(rugr,A)  # Fit a preference tree

summary(eba)  # goodness of fit
ci = 1.96*sqrt(diag(cov.u(eba)))  # 95\%-ci of the preference scale

a = barplot(eba$u,ylim=c(0,.35))  # plot the scale
arrows(a,eba$u-ci,a,eba$u+ci,.05,90,3)  # error bars
}
\keyword{models}

\eof
\name{boot}
\alias{boot}
\alias{eba.boot}
\title{Bootstrap for Elimination-by-aspects models}
\description{
  Performs a bootstrap by resampling the individual data matrices.
}
\usage{
  boot(D, R = 100, A = 1:I, s = rep(1/J, J))
}
\arguments{
  \item{D}{a 3d array consisting of the individual paired
    comparison matrices}
  \item{R}{the number of bootstrap samples}
  \item{A}{a list of vectors consisting of the stimulus aspects;
    the default is 1:I, where I is the number of stimuli}
  \item{s}{the starting vector with default 1/J for all parameters,
    where J is the number of parameters}
}
\details{
  The bootstrap function eba.boot is called automatically by boot.
}
\value{
  \item{p}{the matrix of bootstrap vectors}
  \item{stat}{the matrix of bootstrap statistics, including parameter
    means, standard errors, and confidence limits}}
}
\author{Florian Wickelmaier \email{wickelmaier@web.de}}
\seealso{
  \code{\link{OptiPt}}.
}
\examples{
data(pork)  # pork tasting data, 10 individual paired comparison matrices
eba = OptiPt(apply(pork,1:2,sum))  # fit a BTL model
b = boot(pork,200)  # resample 200 times

plot(eba$estimate,b$stat[,'mean'],log='xy')
abline(0,1,lty=3)
}
\keyword{models}

\eof
\name{cov.u}
\alias{cov.u}
\title{Covariance of the u-scale}
\description{
  Computes the covariance matrix of the u-scale from the covariance
  matrix of the parameters.
}
\usage{cov.u(eba)}
\arguments{
  \item{eba}{an object of class \code{eba}}
}
\details{
  The additivity law of covariances \eqn{cov(x+y,z) = cov(x,z)+cov(y,z)}
  is used for the computations.
}
\value{
  the covariance matrix of the u-scale
}
\author{Florian Wickelmaier \email{wickelmaier@web.de}}
\seealso{
  \code{\link{OptiPt}}.
}
\keyword{models}

\eof
\name{pork}
\alias{pork}
\title{Pork tasting data}
\description{
  This data set provides the individual choice matrices
  of two judges choosing between pairs of three samples
  of pork meet. Each judge does five repetitions. The
  data are stored in a 3d array, the first five matrices
  of which correspond to the five repetitions of the first
  judge, the last five to the repetitions of the second
  judge. Row stimuli are chosen over column stimuli.
}
\usage{data(pork)}
\format{A 3d array consisting of ten square matrices.}
\references{
  Bradley, R.A., & Terry, M.E. (1952).
  Rank analysis of incomplete block designs.
  I. The method of paired comparisons.
  \emph{Biometrika}, \bold{39}, 324-345.
}
\keyword{datasets}

\eof
\name{rugr}
\alias{rugr}
\title{Choice among celebrities}
\description{
  This data set provides the absolute choice frequencies of
  234 subjects choosing between pairs of nine celebrities.
  LBJ, HW, and CDG are politicians; JU, CY, and AJF are
  athletes; BB, ET, and SL are female movie stars.
  Row stimuli are chosen over column stimuli.
}
\usage{data(rugr)}
\format{A square data frame with a diagonal of zeros.}
\references{
  Rumelhart, D.L., & Greeno, J.G. (1971).
  Similarity between stimuli: An experimental test of the
  Luce and Restle choice models.
  \emph{Journal of Mathematical Psychology}, \bold{8}, 370-381.
}
\keyword{datasets}

\eof
\name{strans}
\alias{strans}
\alias{print.strans}
\title{Stochastic Transitivity}
\description{
  Checks the weak, moderate, and strong stochastic transitivity.
}
\usage{strans(M)}
\arguments{
  \item{M}{a square matrix or a data frame consisting of
    absolute frequencies}
}
\details{
  With erroneous data, the number of violations is only a descriptive
  index of the goodness of fit of a model. When the sample size is small
  (or too large), however, the violations might be the only reliable
  index for the model selection.
}
\value{
  A table displaying the number of violations of the weak, moderate,
  and strong stochastic transitivity, the number of tests, the
  error ratio (violations/tests), and the mean and maximum deviation.
  \item{pcm}{the square matrix of relative choice frequencies}
}
\seealso{\code{\link{OptiPt}}.}
\examples{
data(rugr)  # absolute choice frequencies
strans(rugr)  # report of the transitivity violations
strans(rugr)$pcm  # relative frequencies
}
\keyword{models}

\eof
